/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef GSH_UPDATED_H
#define GSH_UPDATED_H

struct gsh_updated_struct
{
	void *next;
	void (*function)(char *, void *);
	char *command;
	void *widget;
};

void
gsh_add_to_updates(struct gsh_updated_struct *update);

void
gsh_add_update(void (*function)(char *, void *),
        char *command, void *widget);

void    
gsh_update_label(char *command, void *widget);

void    
gsh_add_updated_label(char *command);

void    
gsh_start_updates();

gint
gsh_perform_updates(gpointer data);

#endif

